# **tygle**

**Ty**ped Goo**gle** or simply *~~tiger~~* tygle.  
Created using [Aiogoogle](https://github.com/omarryhan/aiogoogle) for interaction with Google APIs and [pydantic](https://github.com/samuelcolvin/pydantic) for typing.

## Work In Progress
🛑 This is a WIP package. Expect bugs and changes.

## Installation
In order to install the package, install tygle itself and the APIs you need.  
For example: `pip install tygle[sheets]`

## Supported APIs
Currently, tygle only supports following APIs:  
1. [Sheets](https://github.com/typed-google/tygle-sheets) – `tygle[sheets]`
2. [Drive](https://github.com/typed-google/tygle-drive) – `tygle[drive]`